@@ -184,7 +184,7 @@ def ms_runner(file, ms_offset=None, norm=True):
             lambda x: x - (ms_offset / 60)
         )
         data_frame = data_frame[data_frame.index >= 0]
-    data_frame["Absorbance"] = data_frame["Absorbance"].ewm(span=5).mean()
+    data_frame["Abundance"] = data_frame["Abundance"].ewm(span=5).mean()
     if norm:
         data_frame = series_normalizer(data_frame)
     return data_frame
