@@ -60,7 +60,7 @@ def write_topic_structured_csv(frames, method, out_path, wavelengths):
 def gather_meta(topic, name, method, isograd, wavelengths, path, frame):
     meta_frame = base_meta_frame(isograd, name, path, topic)
     if method == "IR":
-        meta_frame = ir_meta(topic, name, isograd, wavelengths, path, frame)
+        meta_frame = ir_meta(topic, name, isograd, wavelengths, path)
     if method == "MS":
         meta_frame = ms_meta(topic, name, isograd, path, frame)
     if method == "STA":
@@ -70,7 +70,9 @@ def gather_meta(topic, name, method, isograd, wavelengths, path, frame):
     return meta_frame
 
 
-def ir_meta(topic, name, isograd, wavelengths, path, frame):
+def ir_meta(
+    topic, name, isograd, wavelengths, path,
+):
     meta_frame = base_meta_frame(isograd, name, path, topic)
     wavelengths = [n for n in wavelengths if n]
     if wavelengths:
@@ -148,6 +150,3 @@ def base_meta_frame(isograd, name, path, topic):
     meta_frame.index.name = "Topic"
     meta_frame = meta_frame.reset_index()
     return meta_frame
-
-
-# data_set = [(k, *t) for k, v in tracer.items() for t in v]
